@@ -93,7 +93,7 @@ use IO::Socket::INET;
 
 use vars qw($VERSION);
 
-$VERSION = '1.6';
+$VERSION = '1.62';
 
 
 $Lock::Server::DEBUG = 0;
@@ -210,6 +210,7 @@ sub _create_listener_socket {
             Listen    => 10,
             LocalAddr => "$self->{host}:$self->{port}",
             );
+        last if $listener_socket;
         print STDERR "Unable to open the lock server socket. Retry $count of 10\n";
         sleep $count*$self->{time_between_attempts} unless $listener_socket;
     }
@@ -445,7 +446,7 @@ use IO::Socket::INET;
 
 use vars qw($VERSION);
 
-$VERSION = '1.6';
+$VERSION = '1.62';
 
 
 =head3 new( lockername, host, port )
@@ -566,6 +567,6 @@ __END__
 
 =head1 VERSION
 
-       Version 1.6  (Mar 9, 2016))
+       Version 1.62  (May 6, 2016))
 
 =cut
